@@ -29,8 +29,15 @@ const test = function test<Args extends unknown[]>(
 };
 
 test.macro = ava.macro;
-test.only = <Args extends unknown[]>(label: string, fn: Implementation<Args>, ...args: Args) => {
+test['only'] = <Args extends unknown[]>(label: string, fn: Implementation<Args>, ...args: Args) => {
   ava.only(getLabel(label), fn, ...args);
 };
+test.skip = function skip<Args extends unknown[]>(
+  label: string,
+  fn: Implementation<Args>,
+  ...args: Args
+): void {
+  ava.skip(getLabel(label), fn, ...args);
+};
 
 export { test, describe, describe as context };
